@@ -1,13 +1,13 @@
 #[macro_use]
 extern crate nom;
-#[macro_use]
-extern crate arrayref;
 #[cfg(feature = "derive")]
 #[macro_use]
 extern crate serde_derive;
 
 pub mod arp;
 pub mod ethernet;
+pub mod ip;
 pub mod ipv4;
+pub mod ipv6;
 pub mod tcp;
 pub mod udp;
